@@ -1,5 +1,8 @@
 <?php
 
+if (!defined("_ECRIRE_INC_VERSION"))
+	return;
+
 /*
  * Sauvegarder la connexion apres le spip_connect_db
  */ 
@@ -28,6 +31,4 @@ function mutu_close(){
 	$f($GLOBALS['connexions'][_INSTALL_SERVER_DB]['link']);
 }
 
-
-
 ?>
